package com.qmth.distributed.print.business.service;

import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.service.IService;
import com.qmth.distributed.print.business.bean.params.analyze.AbleAnalyzePaperParam;
import com.qmth.distributed.print.business.bean.params.analyze.GradeBatchPaperParam;
import com.qmth.distributed.print.business.bean.result.analyze.GradeBatchPaperResult;
import com.qmth.distributed.print.business.entity.GradeBatchPaper;
import com.qmth.teachcloud.common.entity.SysUser;

import java.util.List;

/**
 * <p>
 * 分析-批次试卷关联关系表 服务类
 * </p>
 *
 * @author wangliang
 * @since 2022-05-20
 */
public interface GradeBatchPaperService extends IService<GradeBatchPaper> {
    /**
     * 查询批次试卷分页数据
     *
     * @param semesterId    学期id
     * @param examId        考试id
     * @param basicCourseId 基础课程id
     * @param pageNumber    分页页数
     * @param pageSize      分页容量
     * @param requestUser   请求用户
     * @return 分页结果
     */
    IPage<GradeBatchPaperResult> findGradeBatchPaperPage(Long semesterId, Long examId, Long basicCourseId, int pageNumber, int pageSize, SysUser requestUser);

    /**
     * 查询可以作为分析样本的试卷
     * @param semesterId 学期id
     * @param examId 考试id
     * @param collegeId 学院id
     * @param basicCourseId 基础课程id
     * @param teacherName 命题教师
     * @param requestUser 请求用户
     * @return 试卷结果
     */
    List<GradeBatchPaperResult> findAbleAnalyzePaperList(Long semesterId, Long examId, Long collegeId,Long basicCourseId, String teacherName, SysUser requestUser);

    void saveGradeBatchPaper(GradeBatchPaperParam gradeBatchPaperParam, SysUser requestUser);

    boolean deleteGradeBatchPaper(List<Long> idList);

    GradeBatchPaper findByThirdExamIdAndGradeCourseCode(String thirdExamId, String gradeCourseCode);
}
