package com.qmth.distributed.print.business.service.impl;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.qmth.distributed.print.business.bean.dto.open.PaperDimension;
import com.qmth.distributed.print.business.bean.params.GradePaperDimensionParam;
import com.qmth.distributed.print.business.entity.GradePaperDimension;
import com.qmth.distributed.print.business.mapper.GradePaperDimensionMapper;
import com.qmth.distributed.print.business.service.GradePaperDimensionService;
import com.qmth.teachcloud.common.contant.SystemConstant;
import com.qmth.teachcloud.common.entity.SysUser;
import com.qmth.teachcloud.common.enums.ExceptionResultEnum;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;
import org.springframework.web.multipart.MultipartFile;

import java.util.List;
import java.util.Objects;

/**
 * <p>
 * 分析-考察点维度表 服务实现类
 * </p>
 *
 * @author wangliang
 * @since 2022-05-20
 */
@Service
public class GradePaperDimensionServiceImpl extends ServiceImpl<GradePaperDimensionMapper, GradePaperDimension> implements GradePaperDimensionService {

    @Transactional(rollbackFor = Exception.class)
    @Override
    public Long editGradePaperDimension(GradePaperDimensionParam gradePaperDimensionParam, SysUser requestUser) {
        Long id = gradePaperDimensionParam.getId();
        Long schoolId = requestUser.getSchoolId();
        // 基础信息
        String paperNumber = gradePaperDimensionParam.getPaperNumber();
        String paperType = gradePaperDimensionParam.getPaperType();
        String paperName = gradePaperDimensionParam.getPaperName();

        // TODO: 2022/5/23 根据试卷编号和试卷类型校验该试卷是分析试卷

        // 维度信息
        String codePrimary = gradePaperDimensionParam.getCodePrimary();
        String namePrimary = gradePaperDimensionParam.getNamePrimary();
        this.checkCodePrimaryParams(id, paperNumber, paperType, codePrimary, namePrimary, schoolId);

        // 二级维度


        return null;
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public void editGradePaperDimensionBatch(List<GradePaperDimensionParam> gradePaperDimensionParamList, SysUser requestUser) {

    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public void deleteGradePaperDimension(List<Long> gradePaperDimensionIdList) {

    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public void importGradePaperDimension(MultipartFile file, String paperNumber, String paperType, SysUser requestUser) {

    }

    @Override
    public void exportGradePaperDimensionTemplate(String paperNumber, String paperType, SysUser requestUser) {

    }

    @Override
    public PaperDimension findBySchoolIdAndPaperNumberAndPaperType(Long schoolId, String paperNumber, String paperType) {
        return this.baseMapper.findBySchoolIdAndPaperNumberAndPaperType(schoolId, paperNumber, paperType);
    }

    /**
     * 检验一级维度参数
     *
     * @param id          主键
     * @param paperNumber 试卷编号
     * @param paperType   试卷类型
     * @param codePrimary 一级维度编号
     * @param namePrimary 一级维度名称
     * @param schoolId    学校id
     */
    private void checkCodePrimaryParams(Long id, String paperNumber, String paperType, String codePrimary, String namePrimary, Long schoolId) {
        if (SystemConstant.isOneNull(paperNumber, paperType, codePrimary, namePrimary)) {
            throw ExceptionResultEnum.PARAMS_ERROR.exception();
        }

        if (!codePrimary.matches(SystemConstant.REGULAR_EXPRESSION_OF_CODE_PRIMARY_DIMENSION)) {
            throw ExceptionResultEnum.ERROR.exception("一级维度编号必须为大写A-Z");
        }
        List<GradePaperDimension> gradePaperDimensionList = this.list(new QueryWrapper<GradePaperDimension>().lambda()
                .eq(GradePaperDimension::getPaperNumber, paperNumber)
                .eq(GradePaperDimension::getPaperType, paperType)
                .eq(GradePaperDimension::getCodePrimary, codePrimary)
                .eq(GradePaperDimension::getSchoolId, schoolId));

        if (gradePaperDimensionList.size() > 1) {
            if (!namePrimary.equals(gradePaperDimensionList.get(0).getNamePrimary())) {
                throw ExceptionResultEnum.ERROR.exception("一级维度编码和名称不一致");
            }
        } else {
            GradePaperDimension gradePaperDimension = gradePaperDimensionList.get(0);
            if (!namePrimary.equals(gradePaperDimension.getNamePrimary())) {
                if (!Objects.equals(gradePaperDimension.getId(), id)) {
                    throw ExceptionResultEnum.ERROR.exception("一级维度编码和名称不一致");
                }
            }
        }
    }
}
