package com.qmth.distributed.print.api;

import com.alibaba.fastjson.JSONObject;
import com.qmth.boot.api.constant.ApiConstant;
import com.qmth.distributed.print.business.service.OpenApiService;
import com.qmth.teachcloud.common.util.Result;
import com.qmth.teachcloud.common.util.ResultUtil;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiResponse;
import io.swagger.annotations.ApiResponses;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.*;

import javax.annotation.Resource;

/**
 * <p>
 * 知学知考开放接口前端控制器
 * </p>
 *
 * @author wangliang
 * @since 2022-04-26
 */
@Api(tags = "知学知考开放接口Controller")
@RestController
@RequestMapping(ApiConstant.DEFAULT_URI_PREFIX + "/${prefix.url.open}")
@Validated
public class OpenApiController {
    private final static Logger log = LoggerFactory.getLogger(OpenApiController.class);

    @Resource
    private OpenApiService openApiService;

    @ApiOperation(value = "查询教研分析数据(1.蓝图数据，2.考生作答数据)")
    @ApiResponses({@ApiResponse(code = 200, message = "查询教研分析数据(1.蓝图数据，2.考生作答数据)", response = Object.class)})
    @RequestMapping(value = "/analysis/data", method = RequestMethod.POST)
    public Result analysisData(JSONObject jsonObject) {
        return ResultUtil.ok(true);
    }

    /**
     * 试卷基础配置查询
     *
     * @param thirdExamId     第三方考试id
     * @param gradeCourseCode 第三方课程编号
     */
    @ApiOperation(value = "试卷基础配置查询")
    @ApiResponses({@ApiResponse(code = 200, message = "试卷基础配置查询", response = Object.class)})
    @PostMapping("/paper_config")
    public Result paperConfig(@RequestParam String thirdExamId,
                              @RequestParam String gradeCourseCode) {
        return ResultUtil.ok(openApiService.getPaperConfig(thirdExamId, gradeCourseCode));
    }

    /**
     * 试卷考察点查询
     *
     * @param thirdExamId     第三方考试id
     * @param gradeCourseCode 第三方课程编号
     */
    @ApiOperation(value = "试卷考察点查询")
    @ApiResponses({@ApiResponse(code = 200, message = "试卷考察点查询", response = Object.class)})
    @PostMapping("/paper_dimension")
    public Result paperDimension(@RequestParam String thirdExamId,
                                 @RequestParam String gradeCourseCode) {
        return ResultUtil.ok(openApiService.getPaperDimension(thirdExamId, gradeCourseCode));
    }

    /**
     * 试卷蓝图查询
     *
     * @param thirdExamId     第三方考试id
     * @param gradeCourseCode 第三方课程编号
     */
    @ApiOperation(value = "试卷蓝图查询")
    @ApiResponses({@ApiResponse(code = 200, message = "试卷蓝图查询", response = Object.class)})
    @PostMapping("/paper_structure")
    public Result paperStructure(@RequestParam String thirdExamId,
                                 @RequestParam String gradeCourseCode) {
        return ResultUtil.ok(openApiService.getPaperStructure(thirdExamId, gradeCourseCode));
    }

    /**
     * 试卷评价模型查询
     *
     * @param thirdExamId     第三方考试id
     * @param gradeCourseCode 第三方课程编号
     */
    @ApiOperation(value = "试卷评价模型查询")
    @ApiResponses({@ApiResponse(code = 200, message = "试卷评价模型查询", response = Object.class)})
    @PostMapping("/paper_evaluation")
    public Result paperEvaluation(@RequestParam String thirdExamId,
                                  @RequestParam String gradeCourseCode) {
        return ResultUtil.ok(openApiService.getPaperEvaluation(thirdExamId, gradeCourseCode));
    }

    /**
     * 考生成绩查询
     *
     * @param thirdExamId     第三方考试id
     * @param gradeCourseCode 第三方课程编号
     */
    @ApiOperation(value = "考生成绩查询")
    @ApiResponses({@ApiResponse(code = 200, message = "考生成绩查询", response = Object.class)})
    @PostMapping("/exam_student_score")
    public Result examStudentScore(@RequestParam String thirdExamId,
                                   @RequestParam String gradeCourseCode) {
        return ResultUtil.ok(true);
    }
}
